..
    Copyright (C) 2023 CERN.

    Invenio-Notifications is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version 0.2.0 (released 2023-06-06)

- views: register notification settings menu
- backends: render template fully once to establish context

Version 0.1.1 (released 2023-05-05)

- remove type hints

Version 0.1.0 (released 2023-05-04)

- Initial public release.
